.. _Optimus: https://github.com/sveetch/Optimus

This is the Readme file for the `Optimus`_ project : $PROJECT_NAME

Read the Optimus documentation on `<https://optimus.readthedocs.org/>`_.

The ``gemsets.txt`` file contains the list of the required Ruby gems you will need to install to compile the SCSS sources with Compass.